==> jc-1.4.0.tar.gz: java/security/spec/DSAPublicKeySpec.h <==
// public class java.security.spec.DSAPublicKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e16a98c9d4bd4893 java_security_spec_DSAPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAPublicKeySpec_H_
#define _JC_java_security_spec_DSAPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAPublicKeySpec$sub_refs	_jc_java_security_spec_DSAPublicKeySpec$sub_refs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs	_jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$refs	_jc_java_security_spec_DSAPublicKeySpec$refs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$nonrefs	_jc_java_security_spec_DSAPublicKeySpec$nonrefs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$object	_jc_java_security_spec_DSAPublicKeySpec$object;

typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vmethods	_jc_java_security_spec_DSAPublicKeySpec$vmethods;
typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vtable	_jc_java_security_spec_DSAPublicKeySpec$vtable;
typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vtype	_jc_java_security_spec_DSAPublicKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAPublicKeySpec$method$_init$af886985c1050c26(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
extern void _jc_java_security_spec_DSAPublicKeySpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getY$e067a5f1fb934d2a;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_DSAPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAPublicKeySpec$vmethods	java_security_spec_DSAPublicKeySpec;
};

// Vtype
struct _jc_java_security_spec_DSAPublicKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*y;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAPublicKeySpec$refs {
    _jc_java_security_spec_DSAPublicKeySpec$sub_refs	java_security_spec_DSAPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs	java_security_spec_DSAPublicKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAPublicKeySpec$object {
	_jc_java_security_spec_DSAPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAPublicKeySpec$vtype	*vtype;
	_jc_java_security_spec_DSAPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAPublicKeySpec$vtype _jc_java_security_spec_DSAPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAPublicKeySpec$class_object;

#endif	/* _JC_java_security_spec_DSAPublicKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/DSAPublicKeySpec.h <==
// public class java.security.spec.DSAPublicKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e16a98c9d4bd4893 java_security_spec_DSAPublicKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAPublicKeySpec_H_
#define _JC_java_security_spec_DSAPublicKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAPublicKeySpec$sub_refs	_jc_java_security_spec_DSAPublicKeySpec$sub_refs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs	_jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$refs	_jc_java_security_spec_DSAPublicKeySpec$refs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$nonrefs	_jc_java_security_spec_DSAPublicKeySpec$nonrefs;
typedef struct _jc_java_security_spec_DSAPublicKeySpec$object	_jc_java_security_spec_DSAPublicKeySpec$object;

typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vmethods	_jc_java_security_spec_DSAPublicKeySpec$vmethods;
typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vtable	_jc_java_security_spec_DSAPublicKeySpec$vtable;
typedef const struct _jc_java_security_spec_DSAPublicKeySpec$vtype	_jc_java_security_spec_DSAPublicKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAPublicKeySpec$method$_init$af886985c1050c26(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAPublicKeySpec$method$getY$e067a5f1fb934d2a(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_spec_DSAPublicKeySpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$getY$e067a5f1fb934d2a;
extern _jc_method _jc_java_security_spec_DSAPublicKeySpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAPublicKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getY$e067a5f1fb934d2a)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAPublicKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_DSAPublicKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAPublicKeySpec$vmethods	java_security_spec_DSAPublicKeySpec;
};

// Vtype
struct _jc_java_security_spec_DSAPublicKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAPublicKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAPublicKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*y;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAPublicKeySpec$refs {
    _jc_java_security_spec_DSAPublicKeySpec$sub_refs	java_security_spec_DSAPublicKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAPublicKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAPublicKeySpec$sub_nonrefs	java_security_spec_DSAPublicKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAPublicKeySpec$object {
	_jc_java_security_spec_DSAPublicKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAPublicKeySpec$vtype	*vtype;
	_jc_java_security_spec_DSAPublicKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAPublicKeySpec$vtype _jc_java_security_spec_DSAPublicKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAPublicKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAPublicKeySpec$class_object;

#endif	/* _JC_java_security_spec_DSAPublicKeySpec_H_ */
